@@ -6,18 +6,6 @@ isNA <- function(x) {
   is.logical(x) && length(x) == 1L && is.na(x)
 }
 
-stopf <- function(fmt, ..., call. = TRUE, domain = NULL) {  #nolint
-  stop(sprintf(fmt, ...), call. = call., domain = domain)
-}
-
-warnf <- function(fmt, ..., call. = TRUE, immediate. = FALSE, domain = NULL) {  #nolint
-  warning(sprintf(fmt, ...), call. = call., immediate. = immediate., domain = domain)
-}
-
-msgf <- function(fmt, ..., appendLF = FALSE, domain = NULL) {  #nolint
-  message(sprintf(fmt, ...), appendLF = appendLF, domain = domain)
-}
-
 stop_if_not <- function(...) {
   res <- list(...)
   for (ii in 1L:length(res)) {
@@ -102,16 +90,18 @@ mstr <- function(..., appendLF = TRUE, debug = NA) {
   message(paste(now(), capture.output(str(...)), sep = "", collapse = "\n"), appendLF = appendLF)
 }
 
-## When 'default' is specified, this is 30x faster than
-## base::getOption().  The difference is that here we use
-## use names(.Options) whereas in 'base' names(options())
-## is used.
-getOption <- local({
-  go <- base::getOption
-  function(x, default = NULL) {
-    if (missing(default) || match(x, table = names(.Options), nomatch = 0L) > 0L) go(x) else default
-  }
-}) ## getOption()
+if (getRversion() < "4.0.0") {
+  ## When 'default' is specified, this is 30x faster than
+  ## base::getOption().  The difference is that here we use
+  ## use names(.Options) whereas in 'base' names(options())
+  ## is used.
+  getOption <- local({
+    go <- base::getOption
+    function(x, default = NULL) {
+      if (missing(default) || match(x, table = names(.Options), nomatch = 0L) > 0L) go(x) else default
+    }
+  })
+}
 
 #' @importFrom future FutureError
 #' @importFrom utils capture.output head str
